var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React from 'react';
import SetRailsAPIService from '../services/rails_api_service';
import { TOGGLE_TENANT_SWITCHER, TOGGLE_SIDEBAR, TENANT_UPDATED, SUBLIST_CLICKED, PAGINATE_BACK, TENANT_UPDATE_ERROR, SELECT_TENANT } from '../constants/tenant_switcher';
import Avatar from 'material-ui/Avatar';
import TenantLookup from '../helpers/tenant_lookup';

import EnvironmentFlag from '../components/side_bar/environment_flag';
import TenantList from '../components/side_bar/tenant_list';

var getLayoutWrapper = function getLayoutWrapper(serverSide) {
  if (serverSide === true) {
    return {};
  }
  return document.getElementById('layout_wrapper');
};

var TenantSwitcherContainer = function (_React$PureComponent) {
  _inherits(TenantSwitcherContainer, _React$PureComponent);

  function TenantSwitcherContainer(props) {
    _classCallCheck(this, TenantSwitcherContainer);

    var _this = _possibleConstructorReturn(this, (TenantSwitcherContainer.__proto__ || Object.getPrototypeOf(TenantSwitcherContainer)).call(this, props));

    Object.defineProperty(_this, 'selectTenant', {
      enumerable: true,
      writable: true,
      value: function value(tenant) {
        return function () {
          _this.updateTenant(tenant);
          _this.props.dispatch({ type: SELECT_TENANT, payload: tenant });
        };
      }
    });
    Object.defineProperty(_this, 'updateTenant', {
      enumerable: true,
      writable: true,
      value: function value(tenant) {
        var _this$props$data = _this.props.data,
            currentUser = _this$props$data.currentUser,
            activeTenant = _this$props$data.activeTenant,
            csrf_token = _this$props$data.csrf_token;

        var self = _this;
        _this.railsAPI.post('/admin_update/tenant_change', {
          active_tenant: activeTenant.id,
          requested_tenant: tenant.id,
          authenticity_token: csrf_token
        }).then(function (response) {
          self.props.dispatch({
            type: TENANT_UPDATED,
            payload: Object.assign({}, currentUser, { active_tenant: response.data })
          });
          self.layoutWrapper.classList.remove('sidebar--tenant-display');
          window.location = '/admin/dashboards'; // TODO: remove when we fully switch to React
        }).catch(function (error) {
          self.props.dispatch({ type: TENANT_UPDATE_ERROR, payload: error });
        });
      }
    });
    Object.defineProperty(_this, 'paginateBack', {
      enumerable: true,
      writable: true,
      value: function value() {
        var parentTenant = _this.props.data.parentTenant;

        _this.props.dispatch({ type: PAGINATE_BACK, payload: _this.tenantLookupTable[parentTenant].parent_id });
      }
    });
    Object.defineProperty(_this, 'subTenantListClicked', {
      enumerable: true,
      writable: true,
      value: function value(parent_id) {
        return function () {
          _this.props.dispatch({ type: SUBLIST_CLICKED, payload: parent_id });
        };
      }
    });
    Object.defineProperty(_this, 'toggleTenantSwitcher', {
      enumerable: true,
      writable: true,
      value: function value() {
        _this.props.dispatch({ type: TOGGLE_TENANT_SWITCHER });
        _this.layoutWrapper.className = !_this.props.data.tenantListActive ? 'sidebar--tenant-display' : '';
      }
    });
    Object.defineProperty(_this, 'toggleSidebar', {
      enumerable: true,
      writable: true,
      value: function value() {
        _this.props.dispatch({ type: TOGGLE_SIDEBAR });
        _this.layoutWrapper.className = _this.props.data.sidebarExpanded ? 'sidebar--collapsed' : '';
      }
    });

    _this.layoutWrapper = getLayoutWrapper(_this.props.railsContext.serverSide);
    _this.railsAPI = SetRailsAPIService(_this.props.railsContext, _this.props.data);
    _this.tenantLookupTable = TenantLookup(_this.props.data.tenants);
    return _this;
  }

  _createClass(TenantSwitcherContainer, [{
    key: 'render',
    value: function render() {
      var _props$data = this.props.data,
          environment = _props$data.environment,
          environment_abbreviated = _props$data.environment_abbreviated,
          currentUser = _props$data.currentUser,
          activeTenant = _props$data.activeTenant,
          parentTenant = _props$data.parentTenant,
          tenantSyncedWithDB = _props$data.tenantSyncedWithDB,
          tenantListActive = _props$data.tenantListActive;


      return React.createElement(
        'footer',
        { id: 'tenant_switch' },
        React.createElement(TenantList, {
          selectTenant: this.selectTenant,
          subTenantListClicked: this.subTenantListClicked,
          paginateBack: this.paginateBack,
          tenantLookupTable: this.tenantLookupTable,
          tenantSyncedWithDB: tenantSyncedWithDB,
          currentUser: currentUser,
          activeTenant: activeTenant,
          parentTenant: parentTenant,
          active: tenantListActive }),
        React.createElement(
          'nav',
          { className: 'demo-navigation mdl-navigation' },
          React.createElement(EnvironmentFlag, { environment: environment, environment_abbreviated: environment_abbreviated }),
          React.createElement(
            'div',
            { onClick: this.toggleTenantSwitcher, className: 'mdl-navigation__link nav__item' },
            React.createElement(
              'div',
              { className: tenantSyncedWithDB === true ? 'sidebar-tenant-icon' : 'hidden' },
              React.createElement(Avatar, { alt: 'Remy Sharp', src: 'https://i.imgur.com/zQA3Cck.png' })
            ),
            React.createElement(
              'span',
              { className: 'nav__item-name nav__item-name--footer' },
              tenantSyncedWithDB === true ? activeTenant.name : 'Loading...'
            ),
            React.createElement(
              'i',
              { className: 'material-icons tenant-toggle',
                role: 'presentation' },
              tenantListActive === true ? 'expand_less' : 'expand_more'
            )
          )
        ),
        React.createElement('div', { className: 'sidebar__toggle-button', onClick: this.toggleSidebar, id: 'sidebar__toggle-button' })
      );
    }
  }]);

  return TenantSwitcherContainer;
}(React.PureComponent);

export default TenantSwitcherContainer;